Learn R Programming

retistruct (version 0.5.9)

Ecart: The deformation energy function

Description

The function that computes the energy (or error) of the deformation of the mesh from the flat outline to the sphere. This depends on the locations of the points given in spherical coordinates. The function is designed to take these as a vector that is received from the optim function.

Usage

Ecart(P, Cu, L, T, A, R, alpha = 1, x0, nu = 1, verbose = FALSE)

Arguments

P
N-by-3 matrix of point coordinates
Cu
The upper part of the connectivity matrix
L
Length of each edge in the flattened outline
T
Triangulation in the flattened outline
A
Area of each triangle in the flattened outline
R
Radius of sphere
alpha
Area penalty scaling coefficient
x0
Area penalty cutoff coefficient
nu
Power to which to raise area
verbose
How much information to report

Value

  • A single value, representing the energy of this particular configuration