Learn R Programming

retistruct (version 0.6.1)

Outline: Outline class

Description

Construct an outline object. This sanitises the input points P, as described below.

Usage

Outline

Arguments

Value

An Outline object containing the following:

P

A N-by-2 matrix of points of the Outline arranged in anticlockwise order

gf

For each row of P, the index of P that is next in the outline travelling anticlockwise (forwards)

gb

For each row of P, the index of P that is next in the outline travelling clockwise (backwards)

h

For each row of P, the correspondence of that point (which will be to itself initially)

im

The image as a raster object

scale

The length of one unit of P in arbitrary units

Format

An object of class R6ClassGenerator of length 25.