Learn R Programming

retistruct (version 0.6.1)

PathOutline: Add point correspondences to the outline

Description

The member function stitchSubpaths() stitches together two subpaths of the outline. One subpath is stitched in the forward direction from the point indexed by VF0 to the point indexed by VF1. The other is stitched in the backward direction from VB0 to VB1. Each point in the subpath is linked to points in the opposing pathway at an equal or near-equal fraction along. If a point exists in the opposing pathway within a distance epsilon of the projection, this point is connected. If no point exists within this tolerance, a new point is created.

Usage

PathOutline

Arguments

Value

To the Outline object this adds

hf

point correspondence mapping in forward direction for points on boundary

hb

point correspondence mapping in backward direction for points on boundary

Format

An object of class R6ClassGenerator of length 25.