Learn R Programming

retistruct (version 0.6.1)

ReconstructedOutline: Reconstruct outline into spherical surface

Description

Reconstruct outline into spherical surface. Reconstruction proceeds in a number of stages:

Usage

ReconstructedOutline

Arguments

Format

An object of class R6ClassGenerator of length 25.

Member functions

mapFlatToSpherical(P)

Returns location of point on sphere corresponding to point on the flat outline. Input values:

P
Cartesian coordinates on flat outline as a matrix with "X" and "Y" columns

Details

  1. The flat object is triangulated with at least n triangles. This can introduce new vertices in the rim.

  2. The triangulated object is stitched.

  3. The stitched object is triangulated again, but this time it is not permitted to add extra vertices to the rim.

  4. The corresponding points determined by the stitching process are merged to form a new set of merged points and a new triangulation.

  5. The merged points are projected roughly to a sphere.

  6. The locations of the points on the sphere are moved so as to minimise the energy function.