Learn R Programming

retistruct (version 0.6.1)

RetinalReconstructedOutline: RetinalReconstructedOutline constructor

Description

Create an object that is specific to retinal datasets. This contains methods that return data point and landmark coordinates that have been transformed according to the values of DVflip and side.

Usage

RetinalReconstructedOutline

Arguments

Value

RetinalReconstructedOutline object. This does not contain any extra fields, but there are extra methods that apply to it.

Format

An object of class R6ClassGenerator of length 25.