Learn R Programming

retistruct (version 0.6.1)

TriangulatedFragment: Triangulate outline

Parameters to constructor: P Points to triangulate n Minimum number of points in the triangulation suppress.external.steiner If TRUE prevent the addition of points in the outline. This happens to maintain triangle quality. report Function to report progress

Description

Create a triangulation of the Fragment object o. The minimum number of triangles in the triangulation is specified by n.

Usage

TriangulatedFragment

Arguments

Value

A triangulatedFragment object containing the following fields:

P

The set of new points, with the existing points at the start

T

The triangulation

Cu

Unique set of M connections, as M*2 matrix

h

Correspondences mapping

A

Array containing area of each triangle

L

Length of each connection

A.signed

Signed area of each triangle

A.tot

Total area of outline

gf

Forward pointers

gb

Backward pointers

S

Segments (from triangulate)

E

Edges (from triangulate)

EB

Edge boundaries (from triangulate)

Format

An object of class R6ClassGenerator of length 25.