Learn R Programming

retistruct (version 0.5.9)

azel.to.sphere.colattitude: Convert azimuth-elevation coordinates to spherical coordinates

Description

Convert azimuth-elevation coordinates to spherical coordinates

Usage

azel.to.sphere.colattitude(r, r0)

Arguments

r
Coordinates of points in azimuth-elevation coordinates represented as 2 column matrix with column names alpha (elevation) and theta (azimuth).
r0
Direction of the axis of the sphere on which to project represented as a 2 column matrix of with column names alpha (elevation) and theta (azimuth).

Value

  • 2-column matrix of spherical coordinates of points with column names psi (colattidude) and lambda (longitude).

Examples

Run this code
r0 <- cbind(alpha=0, theta=0)
r <- rbind(r0, r0+c(1,0), r0-c(1,0), r0+c(0,1), r0-c(0,1))
azel.to.sphere.colattitude(r, r0)

Run the code above in your browser using DataLab