Rdocumentation
powered by
Learn R Programming
retistruct (version 0.5.9)
azimuthal.equidistant: Azimuthal equidistant projection
Description
Azimuthal equidistant projection
Usage
azimuthal.equidistant(r, ...)
Arguments
r
2-column Matrix of spherical coordinates of points on sphere. Column names are
phi
and
lambda
.
...
Arguments not used by this projection.
Value
2-column Matrix of Cartesian coordinates of points on polar projection. Column names should be
x
and
y
.
References
http://en.wikipedia.org/wiki/Map_projection
,
http://mathworld.wolfram.com/AzimuthalEquidistantProjection.html