Learn R Programming

retistruct (version 0.5.9)

create.polar.cart.grid: Create grid on projection of hemisphere onto plane

Description

Create grid on projection of hemisphere onto plane

Usage

create.polar.cart.grid(pa, res, phi0)

Arguments

pa
If TRUE, make this an area-preserving projection
res
Resolution of grid
phi0
Value of phi0 at edge of grid

Value

  • List containing:
  • sGrid locations in spherical coordinates
  • cGrid locations in Cartesian coordinates on plane
  • xsX grid line locations in Cartesian coordinates on plane
  • ysY grid line locations in Cartesian coordinates on plane