Learn R Programming

retistruct (version 0.6.1)

flatplot.ReconstructedOutline: Flat plot of reconstructed outline

Description

Plot ReconstructedOutline object. This adds a mesh of gridlines from the spherical retina (described by points phi, lambda and triangulation Tt and cut-off point phi0) onto a flattened retina (described by points P and triangulation T).

Usage

# S3 method for ReconstructedOutline
flatplot(x, axt = "n", xlim = NULL,
  ylim = NULL, grid = TRUE, strain = FALSE, ...)

Arguments

axt

whether to plot axes

xlim

x-limits

ylim

y-limits

grid

Whether or not to show the grid lines of latitude and longitude

strain

Whether or not to show the strain

...

Other plotting parameters