flipped.triangles.cart: Determine indicies of triangles that are flipped
Description
In the projection of points onto the sphere, some triangles maybe
flipped, i.e. in the wrong orientation. This functions determines
which triangles are flipped by computing the vector pointing to
the centre of each triangle and comparing this direction to vector
product of two sides of the triangle.
Usage
flipped.triangles.cart(P, Tt, R)
Arguments
P
Points in Cartesian coordinates
Tt
Triangulation of points
R
Radius of sphere
Value
List containing:
flippedIndicies of in rows of Tt of flipped triangles.