Learn R Programming

retistruct (version 0.5.9)

getDssHullarea: Get area of convex hull around data points on sphere

Description

Get area of convex hull around data points on sphere

Usage

getDssHullarea(r)

Arguments

Value

  • Area in degress squared