Learn R Programming

retistruct (version 0.5.9)

getDssMean.retinalReconstructedDataset: Get transformed spherical coordinates of Karcher mean of datapoints

Description

Get Karcher mean of datapoints in spherical coordinates, transformed according to the values of DVflip and side.

Usage

## S3 method for class 'retinalReconstructedDataset':
getDssMean(r)

Arguments

Value

  • Dss.mean