getIms.reconstructedOutline: Get coordinates of corners of pixels of image in spherical
coordinates
Description
Get coordinates of corners of pixels of image in spherical
coordinatesUsage
## S3 method for class 'reconstructedOutline':
getIms(r)
Value
- Coordinates of corners of pixels in spherical coordinates