Learn R Programming

retistruct (version 0.5.9)

invert.sphere.to.hemisphere: Invert sphere to hemisphere

Description

Invert image of a partial sphere and scale the longitude so that points at lattitude phi0 is projected onto a longitude of 0 degrees (the equator).

Usage

invert.sphere.to.hemisphere(r, phi0, ...)

Arguments

r
Coordinates of points in spherical coordinates represented as 2 column matrix with column names phi (lattitude) and lambda (longitude).
phi0
The lattitude to map onto the equator
...
Other arguments

Value

  • Matrix in same format, but with pi added to lambda and phi negated and scaled so that the longitude phi0 is projected to 0 degrees (the equator)