Learn R Programming

retistruct (version 0.5.9)

karcher.mean.sphere: Karcher mean on the sphere

Description

The Karcher mean of a set of points on a manifold is defined as the point whose sum of squared Riemmann distances to the points is minimal. On a sphere using sphereical coordinates this distance can be computed using the formula for central angle.

Usage

karcher.mean.sphere(x, na.rm = FALSE, var = FALSE)

Arguments

x
Matrix of points on sphere as N-by-2 matrix with labelled columns \code{phi} (lattitude) and lambda (longitude)
na.rm
logical value indicating whether NA values should be stripped before the computation proceeds.
var
logical value indicating whether variance should be returned too.

Value

  • Vector of means with components named phi and lambda. If var is TRUE, a list containing mean and varience in elements mean and var.

References

Heo, G. and Small, C. G. (2006). Form representations and means for landmarks: A survey and comparative study. Computer Vision and Image Understanding, 102:188-203.

See Also

central.angle