Learn R Programming

retistruct (version 0.5.9)

kde.compute.concentration: Find the optimal concentration for a set of data

Description

Find the optimal concentration for a set of data

Usage

kde.compute.concentration(mu)

Arguments

mu
Data in spherical coordinates

Value

  • The optimal concentration