Learn R Programming

retistruct (version 0.5.9)

kde.fhat.cart: Kernel density estimate on sphere using Fisherian density with Cartesian coordinates

Description

Kernel density estimate on sphere using Fisherian density with Cartesian coordinates

Usage

kde.fhat.cart(r, mu, kappa)

Arguments

r
Locations at which to estimate density in Cartesian coordinates on unit sphere
mu
Locations of data points in Cartesian coordinates on unit sphere
kappa
Concentration parameter

Value

  • Vector of density estimates