Learn R Programming

retistruct (version 0.5.9)

kr.sscv: Cross validation estimate of the least squares error of the points mu given a particular value of the concentration kappa

Description

Cross validation estimate of the least squares error of the points mu given a particular value of the concentration kappa

Usage

kr.sscv(mu, y, kappa)

Arguments

mu
Locations in Cartesian coordinates (independent variables)
y
Values at locations (dependent variables)
kappa
Concentration parameter

Value

  • Least squares error