Learn R Programming

retistruct (version 0.5.9)

kr.yhat.cart: Kernel regression on sphere using Fisherian density with Cartesian coordinates

Description

Kernel regression on sphere using Fisherian density with Cartesian coordinates

Usage

kr.yhat.cart(r, mu, y, kappa)

Arguments

r
Locations at which to estimate dependent variables in Cartesian coordinates
mu
Locations in Cartesian coordinates (independent variables)
y
Values at locations (dependent variables)
kappa
Concentration parameter

Value

  • Estimates of dependent variables at locations r