Learn R Programming

retistruct (version 0.5.9)

labelTearPoints: Label three outline point indicies as apicies and vertices of tear

Description

Label a set of three unlabelled points supposed to refer to the apex and vertcies of a cut and tear with the V0 (Apex), VF (forward vertex) and VB (backward vertex) labels.

Usage

labelTearPoints(o, m)

Arguments

o
Outline object
m
the vector of three indicies

Value

  • Vector of indicies labelled with V0, VF and VB