This function creates merged and transformed versions (all
suffixed with t) of a number of existing variables, as well
as a matrix Bt, which maps a binary vector representation
of edge indices onto a binary vector representation of the
indices of the points linked by the edge.
mergePointsEdges(t)A StitchedOutline object in which points that have
been added by stitching have been triangulated
Adds following fields to input
PtTransformed point locations
TtTransformed triangulation
CtTransformed connection set
CutTransformed symmetric connection set
BtTransformed binary vector representation of edge indices onto a binary vector representation of the indices of the points linked by the edge
LtTransformed edge lengths
htTransformed correspondences
uIndices of unique points in untransformed space
UTransformed indices of unique points in untransformed space
RsetThe set of points on the rim (which has been reordered)
RsettTransformed set of points on rim
i0tTransformed index of the landmark
mapping from edges onto corresponding edges
Transformed mapping from edges onto corresponding edges