Learn R Programming

retistruct (version 0.5.9)

polar.cart.to.sphere.spherical: Convert polar projection in Cartesian coordinates to spherical coordinates on sphere

Description

This is the inverse of sphere.spherical.to.polar.cart

Usage

polar.cart.to.sphere.spherical(r, pa = FALSE, preserve = "lattitude")

Arguments

r
2-column Matrix of Cartesian coordinates of points on polar projection. Column names should be x and y
pa
If TRUE, make this an area-preserving projection
preserve
Quantity to preserve locally in the projection. Options are lattitude, area or angle

Value

  • 2-column Matrix of spherical coordinates of points on sphere. Column names are phi and lambda.