Learn R Programming

retistruct (version 0.5.9)

projection.reconstructedDataset: Plot projection of reconstructed dataset

Description

Plot projection of reconstructed dataset

Usage

## S3 method for class 'reconstructedDataset':
projection(r, transform = identity.transform,
  axisdir = cbind(phi = 90, lambda = 0), projection = azimuthal.equalarea,
  proj.centre = cbind(phi = 0, lambda = 0), lambdalim = c(-180, 180),
  datapoints = TRUE, datapoint.means = TRUE, datapoint.contours = TRUE,
  grouped = FALSE, grouped.contours = FALSE, landmarks = TRUE,
  ids = getIDs(r), ...)

Arguments

transform
Transform function to apply to spherical coordinates before rotation
axisdir
Direction of axis (North pole) of sphere in external space
projection
Projection in which to display object, e.g. azimuthal.equalarea or sinusoidal
proj.centre
Location of centre of projection as matrix with column names phi (elevation) and lambda (longitude).
lambdalim
Limits of longitude (in degrees) to display
datapoints
If TRUE, display data points
datapoint.means
If TRUE, display Karcher mean of data points.
datapoint.contours
If TRUE, display contours around the data points generated using Kernel Density Estimation.
grouped
If TRUE, dipslay grouped data.
grouped.contours
If TRUE, display contours around the grouped data generated using Kernel Regression.
landmarks
If TRUE, dipslay landmarks.
ids
IDs of groups of data within a dataset, returned using getIDs.
...
Graphical parameters to pass to plotting functions