Learn R Programming

retistruct (version 0.5.9)

projection.reconstructedOutline: Projection of a reconstructed outline

Description

Draw a projection of a ReconstructedOutline. This method sets up the grid lines and the angular labels and draws the image.

Usage

## S3 method for class 'reconstructedOutline':
projection(r, transform = identity.transform,
  axisdir = cbind(phi = 90, lambda = 0), projection = azimuthal.equalarea,
  proj.centre = cbind(phi = 0, lambda = 0), lambdalim = c(-180, 180),
  philim = c(-90, 90), labels = c(0, 90, 180, 270), grid = TRUE,
  grid.bg = "transparent", grid.int.minor = 15, grid.int.major = 45,
  colatitude = TRUE, pole = FALSE, image = TRUE, add = FALSE, ...)

Arguments

r
ReconstructedOutline object
transform
Transform function to apply to spherical coordinates before rotation
axisdir
Direction of axis (North pole) of sphere in external space as matrix with column names phi (elevation) and lambda (longitude).
projection
Projection in which to display object, e.g. azimuthal.equalarea or sinusoidal
proj.centre
Location of centre of projection as matrix with column names phi (elevation) and lambda (longitude).
lambdalim
Limits of longitude (in degrees) to display
philim
Limits of latitude (in degrees) to display
labels
Vector of 4 labels to plot at 0, 90, 180 and 270 degrees
grid
Whether or not to show the grid lines of lattitude and longitude
grid.bg
Background colour of the grid
grid.int.minor
Interval between minor grid lines in degrees
grid.int.major
Interval between major grid lines in degrees
colatitude
If TRUE have radial labels plotted with respect to colatitude rather than latitude
pole
If TRUE indicate the pole with a "*"
image
If TRUE, show the image
add
If TRUE, don't draw axes; add to existing plot.
...
Graphical parameters to pass to plotting functions