retistruct.potential.od: Test for a potential optic disc
Description
Test the oputline object o for the prescense of
potential optice disc. This is done by checking that the list of
landmark lines Ss exists.Usage
retistruct.potential.od(o)
Value
TRUE if an optic disc may be present; FALSE otherwise