Read a retinal dataset in one of three formats; for information on
formats see see idt.read.dataset,
csv.read.dataset and
ijroi.read.dataset. The format is autodetected from
the files in the directory.
retistruct.read.dataset(dataset, ...)Path to directory containing the files corresponding to each format.
Parameters passed to the format-specific functions.
An object that of classes RetinalDataset and
RetinalDataset. There may be extra fields too,
depending on the format.