Read the markup data contained in the files markup.csv,
P.csv and T.csv in the directory dataset,
which is specified in the reconstruction object r.
retistruct.read.markup(a, error = stop)Dataset object, containing dataset path
Function to run on error, by default stop()
o RetinalDataset object
Indicies in P of apicies of tears
Indicies in P of backward verticies of tears
Indicies in P of backward verticies of tears
Index in P of nasal point, or NA if not marked
Index in P of dorsal point, or NA if not marked
Index in Ss of optic disc
Angle of rim in degrees
Boolean variable indicating if DV axis has been flipped
The tear information is contained in the files P.csv and
T.csv. The first file contains the locations of outline
points that the tears were marked up on. The second file contains
the indicies of the apicies and backward and forward verticies of
each tear. It is necessary to have the file of points just in case
the algorithm that determines P in
retistruct.read.dataset has changed since the markup
of the tears.
The remaining information is contained containted in the file
markup.csv.
If DVflip is specified, the locations of points P
flipped in the \(y\)-direction. This operation also requires the
swapping of gf and gb and VF and VB.