sphere.cart.to.sphere.dualwedge: Convert from Cartesian to 'dualwedge' coordinates
Description
Convert points in 3D cartesian space to locations of points on
sphere in 'dualwedge' coordinates (fx, fy). Wedges
are defined by planes inclined at angle running through a line
between poles on the rim above the x axis or the y-axis. fx
and fy are the fractional distances along the circle defined
by the intersection of this plane and the curtailed sphere.
Usage
sphere.cart.to.sphere.dualwedge(P, phi0, R = 1)
Arguments
P
locations of points on sphere as N-by-3 matrix with
labelled columns "X", "Y" and "Z"
phi0
rim angle as colatitude
R
radius of sphere
Value
2-column Matrix of 'wedge' coordinates of points on
sphere. Column names are phi and lambda.