sphere.cart.to.sphere.wedge: Convert from Cartesian to 'wedge' coordinates
Description
Convert points in 3D cartesian space to locations of points on
sphere in 'wedge' coordinates (psi, f). Wedges are
defined by planes inclined at an angle psi running through a
line between poles on the rim above the x axis. f is the
fractional distance along the circle defined by the intersection
of this plane and the curtailed sphere.
Usage
sphere.cart.to.sphere.wedge(P, phi0, R = 1)
Arguments
P
locations of points on sphere as N-by-3 matrix with
labelled columns "X", "Y" and "Z"
phi0
rim angle as colatitude
R
radius of sphere
Value
2-column Matrix of 'wedge' coordinates of points on
sphere. Column names are phi and lambda.