Learn R Programming

retistruct (version 0.5.9)

sphere.spherical.to.sphere.cart: Convert from spherical to Cartesian coordinates

Description

Convert locations of points on sphere in spherical coordinates to points in 3D cartesian space

Usage

sphere.spherical.to.sphere.cart(phi, lambda, R = 1)

Arguments

phi
vector of lattitudes of N points
lambda
vector of longitudes of N points
R
radius of sphere

Value

  • An N-by-3 matrix in which each row is the cartesian (X, Y, Z) coordinates of each point