Learn R Programming

retistruct (version 0.5.9)

spherical.to.polar.area: Convert lattitude on sphere to radial variable in area-preserving projection

Description

Project spherical coordinate system $(\phi, \lambda)$ to a polar coordinate system $(\rho, \lambda)$ such that the area of each small region is preserved.

Usage

spherical.to.polar.area(phi, R = 1)

Arguments

phi
Lattitude
R
Radius

Value

  • Coordinate rho that has the dimensions of length

Details

This requires $$R^2\delta\phi\cos\phi\delta\lambda = \rho\delta\rho\delta\lambda$$. Hence $$R^2\int^{\phi}_{-\pi/2} \cos\phi' d\phi' = \int_0^{\rho} \rho' d\rho'$$. Solving gives $\rho^2/2=R^2(\sin\phi+1)$ and hence $$\rho=R\sqrt{2(\sin\phi+1)}$$.

As a check, consider that total area needs to be preserved. If $\rho_0$ is maximum value of new variable then $A=2\pi R^2(\sin(\phi_0)+1)=\pi\rho_0^2$. So $\rho_0=R\sqrt{2(\sin\phi_0+1)}$, which agrees with the formula above.