Try a range of values of phi0s in the reconstruction, recording the energy of the mapping in each case.
titrate.reconstructedOutline(r, alpha = 8, x0 = 0.5, byd = 1,
len.up = 5, len.down = 20)ReconstructedOutline object
Area penalty scaling coefficient
Area cutoff coefficient
Increments in degrees
How many increments to go up from starting value of
phi0 in r.
How many increments to go up from starting value
of phi0 in r.
dat Output data frame