Construct an outline object. This sanitises the input points
P, as described below.
OutlineAn Outline object containing the following:
PA N-by-2 matrix of points of the Outline arranged in anticlockwise order
gfFor each row of P, the index of P that is next in the outline travelling anticlockwise (forwards)
gbFor each row of P, the index of P that is next in the outline travelling clockwise (backwards)
hFor each row of P, the correspondence of that point (which will be to itself initially)
imThe image as a raster object
scaleThe length of one unit of P in arbitrary units
An object of class R6ClassGenerator of length 25.