Parameters to constructor:
P Points to triangulate
n Minimum number of points in the triangulation
suppress.external.steiner If TRUE prevent the
addition of points in the outline. This happens to maintain
triangle quality.
report Function to report progress
Create a triangulation of the Fragment object o. The
minimum number of triangles in the triangulation is specified by
n.
TriangulatedFragmentA triangulatedFragment object containing the
following fields:
PThe set of new points, with the existing points at the start
TThe triangulation
CuUnique set of M connections, as M*2 matrix
hCorrespondences mapping
AArray containing area of each triangle
LLength of each connection
A.signedSigned area of each triangle
A.totTotal area of outline
gfForward pointers
gbBackward pointers
SSegments (from triangulate)
EEdges (from triangulate)
EBEdge boundaries (from triangulate)
An object of class R6ClassGenerator of length 25.