bary.to.sphere.cart: Convert barycentric coordinates of points in mesh on sphere
to cartesian coordinates
Description
Given a triangular mesh on a sphere described by mesh locations
(phi, lambda), a radius R and a triangulation
Tt, determine the Cartesian coordinates of points cb
given in barycentric coordinates with respect to the mesh.
Usage
bary.to.sphere.cart(phi, lambda, R, Tt, cb)
Arguments
phi
Lattitudes of mesh points
lambda
Longitudes of mesh points
R
Radius of sphere
Tt
Triagulation
cb
Object returned by tsearch containing information on the
triangle in which a point occurs and the barycentric coordinates
within that triangle
Value
An N-by-3 matrix of the Cartesian coordinates of the points