Rdocumentation
powered by
Learn R Programming
retistruct (version 0.5.9)
getDssHullarea: Get area of convex hull around data points on sphere
Description
Get area of convex hull around data points on sphere
Usage
getDssHullarea(r)
Arguments
r
code{
ReconstructedDataset
} or
RetinalReconstructedDataset
object.
Value
Area in degress squared