idt.read.dataset: Read one of the Thompson lab's retinal datasets
Description
Read one of the Thompson lab's retinal datasets. Each dataset is a
folder containing a SYS file in SYSTAT format and a MAP file in
text format. The SYS file specifies the locations of the data
points and the MAP file specifies the outline.
Usage
idt.read.dataset(dataset, d.close = 0.25)
Arguments
dataset
Path to directory containing as SYS and MAP file
d.close
Maximum distance between points for them to count
as the same point. This is expressed as a fraction of the width of
the outline.
Value
datasetThe path to the directory given as an argument
rawList containing[object Object],[object Object]
PThe points of the outline
gfForward pointers along the outline
gbBackward pointers along the outline
DsList of datapoints
SsList of landmark lines
Details
The function returns the outline of the retina. In order to do so,
it has to join up the segments of the MAP file. The tracings are
not always precise; sometimes there are gaps between points that
are actually the same point. The parameter d.close specifies
how close points must be to count as the same point.