This function creates merged and transformed versions (all
suffixed with t) of a number of existing variables, as well
as a matrix Bt, which maps a binary vector representation
of edge indicies onto a binary vector representation of the
indicies of the points linked by the edge.
mergePointsEdges(t)A StitchedOutline object in which points that have
been added by stitching have been triangulated
Adds following fields to input
PtTransformed point locations
TtTransformed triangulation
CtTransformed connection set
CutTransformed symmetric connection set
BtTransformed binary vector representation of edge indicies onto a binary vector representation of the indicies of the points linked by the edge
LtTransformed edge lengths
htTransformed correspondences
uIndicies of unique points in untransformed space
UTransformed indicies of unique points in untransformed space
RsetThe set of points on the rim (which has been reoorded)
RsettTransformed set of points on rim
i0tTransformed index of the landmark
mapping from edges onto corresponding edges
Transformed mapping from edges onto corresponding edges