t) of a number of existing variables, as well
as a matrix Bt, which maps a binary vector representation
of edge indicies onto a binary vector representation of the
indicies of the points linked by the edge.mergePointsEdges(t)StitchedOutline object in which points that have
been added by stitching have been triangulatedPtTtCtCutBtLthtuURsetRsetti0t