Learn R Programming

retistruct (version 0.5.9)

retistruct.read.dataset: Read a retinal dataset

Description

Read a retinal dataset in one of three formats; for information on formats see see idt.read.dataset, csv.read.dataset and ijroi.read.dataset. The format is autodetected from the files in the directory.

Usage

retistruct.read.dataset(dataset, ...)

Arguments

dataset
Path to directory containing as SYS and MAP file
...
Parameters passed to the format-specific functions.

Value