Learn R Programming

retistruct (version 0.5.9)

retistruct.read.markup: Read the markup data

Description

Read the markup data contained in the files markup.csv, P.csv and T.csv in the directory dataset, which is specified in the reconstruction object r.

Usage

retistruct.read.markup(a, error = stop)

Arguments

a
Dataset object, containing dataset path
error
Function to run on error, by default stop()

Value

  • o RetinalDataset object
  • V0Indicies in P of apicies of tears
  • VBIndicies in P of backward verticies of tears
  • VFIndicies in P of backward verticies of tears
  • iNIndex in P of nasal point, or NA if not marked
  • iDIndex in P of dorsal point, or NA if not marked
  • iODIndex in Ss of optic disc
  • phi0Angle of rim in degrees
  • DVflipBoolean variable indicating if DV axis has been flipped

Details

The tear information is contained in the files P.csv and T.csv. The first file contains the locations of outline points that the tears were marked up on. The second file contains the indicies of the apicies and backward and forward verticies of each tear. It is necessary to have the file of points just in case the algorithm that determines P in retistruct.read.dataset has changed since the markup of the tears.

The remaining information is contained containted in the file markup.csv.

If DVflip is specified, the locations of points P flipped in the $y$-direction. This operation also requires the swapping of gf and gb and VF and VB.