titrate.reconstructedOutline: Titrate values of phi0
Description
Try a range of values of phi0s in the reconstruction, recording the
energy of the mapping in each case.Usage
titrate.reconstructedOutline(r, alpha = 8, x0 = 0.5, byd = 1,
len.up = 5, len.down = 20)
Arguments
alpha
Area penalty scaling coefficient
x0
Area cutoff coefficient
len.up
How many increments to go up from starting value of
phi0 in r.
len.down
How many increments to go up from starting value
of phi0 in r.